@@ -6,49 +6,81 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Ons wil u graag inlig dat %s die kalender »%s« gepubliseer het.",
     "Open »%s«" : "Open »%s«",
     "Cheers!" : "Geluk!",
+    "Confirm" : "Bevestig",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
+    "New event" : "Nuwe geleentheid",
     "Today" : "Vandag",
     "Day" : "Dag",
     "Week" : "Week",
     "Month" : "Maand",
     "List" : "Lys",
+    "Preview" : "Voorskou",
+    "Copy link" : "Kopieer skakel",
+    "Edit" : "Wysig",
     "Delete" : "Skrap",
+    "Export" : "Voer uit",
     "Share link" : "Deel skakel",
     "Share with users or groups" : "Deel met gebruikers of groepe",
     "No users or groups" : "Geen gebruikers of groepe",
     "can edit" : "kan wysig",
     "New calendar" : "Nuwe kalender",
+    "Name" : "Naam",
+    "Deleted" : "Geskrap",
+    "Restore" : "Herstel",
+    "Delete permanently" : "Skrap permanent",
     "Filename" : "Lêernaam",
     "Cancel" : "Kanselleer",
     "Automatic" : "Outomaties",
+    "List view" : "Lysaansig",
     "Actions" : "Aksies",
     "Show week numbers" : "Toon weeknommers",
     "Location" : "Ligging",
     "Description" : "Beskrywing",
+    "Duration" : "Duur",
+    "to" : "aan",
+    "Add" : "Voeg by",
     "Monday" : "Maandag",
+    "Tuesday" : "Dinsdag",
+    "Wednesday" : "Woensdag",
+    "Thursday" : "Donderdag",
+    "Friday" : "Vrydag",
+    "Saturday" : "Saterdag",
+    "Sunday" : "Sondag",
     "Save" : "Stoor",
     "Update" : "Werk by",
+    "Your email address" : "U e-posadres",
     "Notification" : "Kennisgewing",
     "Email" : "E-pos",
+    "Available" : "Beskikbaar",
+    "Not available" : "Onbeskikbaar",
     "Unknown" : "Onbekend",
+    "Accept" : "Aanvaar",
     "Tentative" : "Tentatief",
     "All day" : "Heeldag",
     "Repeat" : "Herhaal",
     "never" : "nooit",
     "after" : "na",
+    "available" : "beskikbaar",
     "More" : "Nog",
     "Global" : "Globaal",
     "Personal" : "Persoonlik",
     "Details" : "Details",
     "Attendees" : "Bywoners",
+    "Resources" : "Hulpbronne",
     "Close" : "Sluit",
     "Anniversary" : "Herdenking",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Daily" : "Daagliks",
     "Weekly" : "Weekliks",
+    "Prev" : "Vorige",
+    "Next" : "Volgende",
+    "Other" : "Ander",
+    "Status" : "Status",
     "Confirmed" : "Bevestig",
     "Categories" : "Kategorieë",
-    "Mail" : "Pos"
+    "Commuting" : "In die verkeer",
+    "Mail" : "Pos",
+    "Birthday" : "Verjaardag"
 },
 "nplurals=2; plural=(n != 1);");
