@@ -81,11 +81,13 @@ OC.L10N.register(
     "Creating subscription …" : "جاري انشاء اشتراك  …",
     "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
+    "Trash bin" : "المهملات",
     "Name" : "الاسم",
     "Deleted" : "تم حذفه",
     "Restore" : "استعادة ",
     "Delete permanently" : "حذف بشكل دائم",
     "Empty trash bin" : "تفريغ سلة المهملات",
+    "Unknown calendar" : "تقويم غير معروف",
     "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
@@ -118,7 +120,6 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
     "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
     "Show keyboard shortcuts" : "اظهار اختصارات لوحة المفاتيح",
-    "Settings & import" : "الإعدادات و الإستيراد",
     "No reminder" : "لا يوجد تذكير ",
     "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
     "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
