@@ -7,20 +7,36 @@ OC.L10N.register(
     "Day" : "দিবস",
     "Week" : "সপ্তাহ",
     "Month" : "মাস",
+    "Copy link" : "লিঙ্ক কপি করো",
+    "Edit" : "সম্পাদনা",
     "Delete" : "মুছে",
+    "Export" : "রপ্তানি",
     "Share link" : "লিংক ভাগাভাগি করেন",
     "can edit" : "সম্পাদনা করতে পারবেন",
     "New calendar" : "নতুন দিনপঞ্জী",
+    "Name" : "নাম",
+    "Deleted" : "মুছে ফেলা",
+    "Restore" : "ফিরিয়ে দাও",
     "Cancel" : "বাতিল",
     "Automatic" : "স্বয়ংক্রিয়",
     "Actions" : "পদক্ষেপসমূহ",
     "Location" : "অবস্থান",
     "Description" : "বিবরণ",
+    "to" : "প্রতি",
+    "Add" : "যোগ করুন",
     "Monday" : "সোমবার",
+    "Tuesday" : "মঙ্গলবার",
+    "Wednesday" : "বুধবার",
+    "Thursday" : "বৃহস্পতিবার",
+    "Friday" : "শুক্রবার",
+    "Saturday" : "শনিবার",
+    "Sunday" : "রবিবার",
     "Save" : "সংরক্ষণ",
     "Update" : "পরিবর্ধন",
+    "Your email address" : "আপনার ই-মেইল ঠিকানা",
     "Email" : "ইমেইল",
     "Unknown" : "অজানা",
+    "Send email" : "ইমেইল পাঠান ",
     "Repeat" : "পূনঃসংঘটন",
     "never" : "কখনোই নয়",
     "More" : "বেশী",
@@ -30,6 +46,9 @@ OC.L10N.register(
     "Close" : "বন্ধ",
     "Daily" : "দৈনিক",
     "Weekly" : "সাপ্তাহিক",
-    "Mail" : "মেইল"
+    "Next" : "পরবর্তী",
+    "Other" : "অন্যান্য",
+    "Mail" : "মেইল",
+    "Birthday" : "জন্মদিন"
 },
 "nplurals=2; plural=(n != 1);");
