@@ -7,20 +7,36 @@ OC.L10N.register(
     "Day" : "Dan",
     "Week" : "Sedmica",
     "Month" : "Mjesec",
+    "Edit" : "Izmjeni",
     "Delete" : "Obriši",
+    "Export" : "Izvezi",
     "Share link" : "Podijelite vezu",
     "can edit" : "mogu mijenjati",
     "New calendar" : "Novi kalendar",
+    "Name" : "Ime",
+    "Restore" : "Obnovi",
     "Cancel" : "Odustani",
     "Actions" : "Radnje",
     "Location" : "Lokacija",
     "Description" : "Opis",
+    "to" : "do",
+    "Add" : "Dodaj",
     "Monday" : "Ponedjeljak",
+    "Tuesday" : "Utorak",
+    "Wednesday" : "Srijeda",
+    "Thursday" : "Četvrtak",
+    "Friday" : "Petak",
+    "Saturday" : "Subota",
+    "Sunday" : "Nedjelja",
     "Save" : "Spremi",
     "Update" : "Ažuriraj",
+    "Your email address" : "Vaša adresa e-pošte",
     "Email" : "E-pošta",
     "Busy" : "Zauzet",
     "Unknown" : "Nepoznato",
+    "Accept" : "Prihvati",
+    "Decline" : "Odbij",
+    "Send email" : "Pošalji e-poštu",
     "Repeat" : "Ponovi",
     "never" : "nikad",
     "More" : "Više",
@@ -29,7 +45,10 @@ OC.L10N.register(
     "Close" : "Zatvori",
     "Daily" : "Dnevno",
     "Weekly" : "Sedmično",
+    "Next" : "Sljedeće",
+    "Other" : "Ostali",
     "Status" : "Status",
-    "Mail" : "E-Pošta"
+    "Mail" : "E-Pošta",
+    "Birthday" : "Rođendan"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
