@@ -9,8 +9,10 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
     "Open »%s«" : "Åbn »%s«",
     "Cheers!" : "Hav en fortsat god dag.",
+    "Upcoming events" : "Kommende begivenheder",
     "Appointments" : "Aftaler",
     "Confirm" : "Bekræft",
+    "Appointment:" : "Aftale:",
     "Date:" : "Dato:",
     "Where:" : "Hvor:",
     "Description:" : "Beskrivelse:",
@@ -40,6 +42,8 @@ OC.L10N.register(
     "Copy private link" : "Kopier privat link",
     "Export" : "Eksportér",
     "Unshare from me" : "Fjern deling fra mig",
+    "Disable calendar \"{calendar}\"" : "Slå kalender fra {calendar}",
+    "Enable calendar \"{calendar}\"" : "Slå kalender til {calendar}",
     "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
     "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
     "Calendar link copied to clipboard." : "Kalender link kopieret.",
@@ -70,6 +74,7 @@ OC.L10N.register(
     "can edit" : "kan redigere",
     "+ New calendar" : "+ Ny kalender",
     "New calendar" : "Ny kalender",
+    "Name for new calendar" : "Navn på ny kalender",
     "Creating calendar …" : "Opretter kalender…",
     "New calendar with task list" : "Ny kalender med opgaveliste",
     "Creating subscription …" : "Opretter abonnement…",
@@ -86,13 +91,14 @@ OC.L10N.register(
     "or" : "eller",
     "List view" : "Vis som liste",
     "Actions" : "Handlinger",
+    "Editor" : "Editor",
+    "Close editor" : "Luk editor",
     "Enable birthday calendar" : "Slå fødselsdagskalender til",
     "Enable simplified editor" : "Slå simpel editor til",
     "Show weekends" : "Vis weekender",
     "Show week numbers" : "Vis ugenummer ",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Show keyboard shortcuts" : "Vis tastaturgenveje",
-    "Settings & import" : "Indstillinger & importer",
     "No reminder" : "Ingen påmindelse",
     "Location" : "Sted",
     "Description" : "Beskrivelse",
@@ -147,13 +153,22 @@ OC.L10N.register(
     "available" : "tilgængelig",
     "More" : "Mere",
     "Pick a date" : "Vælg en dato",
+    "from {formattedDate}" : "fra {formattedDate}",
+    "to {formattedDate}" : "til {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "til {formattedDate} at {formattedTime}",
     "Global" : "Global",
     "Time:" : "Tid:",
     "Personal" : "Personlig",
+    "No more events today" : "Ikke flere begivenheder i dag",
+    "No upcoming events" : "Ingen kommende begivenheder",
+    "[Today]" : "[i dag]",
+    "[Tomorrow]" : "[I morgen]",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
     "Resources" : "Resourcer",
     "Close" : "Luk",
+    "Subscribe to {name}" : "Abonner på {name}",
     "Anniversary" : "Årsdag",
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Daily" : "Dagligt",
@@ -161,6 +176,7 @@ OC.L10N.register(
     "Untitled event" : "Unavngiven begivenhed",
     "Next" : "Næste",
     "Year" : "År",
+    "No events to display" : "Ingen begivenheder",
     "Other" : "Andet",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
@@ -169,6 +185,8 @@ OC.L10N.register(
     "Confirmed" : "Bekræftet",
     "Canceled" : "Annulleret",
     "Categories" : "Kategorier",
+    "Custom color" : "Brug brugerdefinerede farver",
+    "Commuting" : "Pendler",
     "Presentation" : "Præsentation",
     "Talk" : "Snak",
     "Movie" : "Film",
