@@ -1,6 +1,7 @@
 OC.L10N.register(
     "calendar",
     {
+    "User-Session unexpectedly expired" : "Brukerøkten utløp uventet",
     "Provided email-address is not valid" : "Oppgitt e-postadresse er ikke gyldig",
     "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
     "Unexpected error sending email. Please contact your administrator." : "Det oppstod uventet feil under sending av e-post. Kontakt din administrator.",
@@ -16,7 +17,7 @@ OC.L10N.register(
     "Prepare for %s" : "Forbered for %s",
     "Follow up for %s" : "Følg opp for %s",
     "Your appointment \"%s\" needs confirmation" : "Avtalen din \"%s\" trenger bekreftelse",
-    "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bookingen din",
+    "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bestillingen din",
     "Confirm" : "Bekreft",
     "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
     "If you wish to cancel the appointment after all, please contact your organizer." : "Hvis du ønsker å avlyse avtalen likevel, vennligst kontakt arrangøren din.",
@@ -46,8 +47,6 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
     "Add new" : "Legg til ny",
     "Untitled calendar" : "Kalender uten tittel",
-    "Disable calendar" : "Deaktiver kalender",
-    "Enable calendar" : "Aktiver kalender",
     "Edit name" : "Rediger navn",
     "Saving name …" : "Lagrer navn ...",
     "Edit color" : "Rediger farge",
@@ -55,6 +54,9 @@ OC.L10N.register(
     "Copy private link" : "Kopier privat lenke",
     "Export" : "Eksporter",
     "Unshare from me" : "Fjern deling fra meg",
+    "Disable calendar \"{calendar}\"" : "Deaktiver kalender \"{calendar}\"",
+    "Disable untitled calendar" : "Deaktiver kalender uten tittel",
+    "Enable untitled calendar" : "Aktiver kalender uten tittel",
     "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
     "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
     "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
@@ -105,25 +107,24 @@ OC.L10N.register(
     "You do not have any deleted elements." : "Du har ingen slettede elementer.",
     "Name" : "Navn",
     "Deleted" : "Slettet",
-    "Restore" : "Gjenoprett",
-    "Delete permanently" : "Slett permament",
+    "Restore" : "Gjenopprett",
+    "Delete permanently" : "Slett permanent",
     "Empty trash bin" : "Tøm papirkurv",
     "Untitled element" : "Element uten tittel",
     "Unknown calendar" : "Ukjent kalender",
     "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
     "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
     "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
-    "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendrene.",
+    "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
     "Filename" : "Filnavn",
     "Calendar to import into" : "Kalenderen det skal importeres til",
     "Cancel" : "Avbryt",
     "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
-    "{filename} is an unsupported file-type" : "{filename} er en ustøttet filtype",
     "{filename} could not be parsed" : "{filename} kunne ikke leses",
     "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
-    "Import partially failed. Imported {accepted} out of {total}." : "Importering mislykkes delvis. Importerte {accepted} av {total}. ",
+    "Import partially failed. Imported {accepted} out of {total}." : "Importen mislyktes delvis. Importerte {accepted} av {total}. ",
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
@@ -138,24 +139,43 @@ OC.L10N.register(
     "Month view" : "Månedsvisning",
     "List view" : "Listevisning",
     "Actions" : "Handlinger",
-    "Create event" : "Opprettet hendelse",
+    "Create event" : "Opprett hendelse",
     "Show shortcuts" : "Vis snarveier",
+    "Save edited event" : "Lagre endret hendelse",
+    "Delete edited event" : "Slett endret hendelse",
+    "Duplicate event" : "Dupliser hendelse",
     "Enable birthday calendar" : "Aktiver fødselsdagkalender",
     "Show tasks in calendar" : "Vis oppgaver i kalender",
     "Enable simplified editor" : "Aktiver forenklet redigering",
     "Limit visible events per view" : "Begrens synlige hendelser i brukerutsnitt",
     "Show weekends" : "Vis helger",
-    "Show week numbers" : "Vis ukenumre",
-    "Copy primary CalDAV address" : "Kopier hovedlenke til CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Kopier iOS/macOS CalDAV-lenke",
+    "Show week numbers" : "Vis ukenummer",
+    "Time increments" : "Tidsøkninger",
+    "Default reminder" : "Standardpåminnelse",
+    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
+    "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
     "Show keyboard shortcuts" : "Vis tastatursnarveier",
-    "Settings & import" : "Innstillinger og import",
-    "CalDAV link copied to clipboard." : "CalDAV lenke kopiert til utklippstavlen.",
+    "Calendar settings" : "Kalenderinnstillinger",
+    "No reminder" : "Ingen påminnelse",
+    "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutt","{duration} minutter"],
+    "0 minutes" : "0 minutter",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
+    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dager"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} uke","{duration} uker"],
+    "_{duration} month_::_{duration} months_" : ["{duration} måned","{duration} måneder"],
+    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
     "Location" : "Sted",
     "Description" : "Beskrivelse",
+    "Visibility" : "Synlighet",
     "Duration" : "Varighet",
+    "Increments" : "Økninger",
+    "Additional calendars to check for conflicts" : "Ekstra kalendere for å se etter konflikter",
+    "Pick time ranges where appointments are allowed" : "Velg tidsrom der avtaler er tillatt",
     "to" : "til",
+    "Delete slot" : "Slett tidsrom",
+    "No times set" : "Ingen tidsrom satt",
     "Add" : "Legg til",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
@@ -164,9 +184,20 @@ OC.L10N.register(
     "Friday" : "Fredag",
     "Saturday" : "Lørdag",
     "Sunday" : "Søndag",
+    "Before the event" : "Før hendelsen",
+    "After the event" : "Etter hendelsen",
+    "Minimum time before next available slot" : "Minimumstid før neste tilgjengelige tidsrom",
+    "Max slots per day" : "Maks. antall tidsrom per dag",
+    "Limit how far in the future appointments can be booked" : "Begrens hvor langt frem i tid avtaler kan bestilles",
+    "Create appointment" : "Opprett avtale",
+    "Edit appointment" : "Endre avtale",
     "Save" : "Lagre",
     "Update" : "Oppdater",
+    "Please confirm your reservation" : "Vennligst bekreft din reservasjon",
+    "Your name" : "Ditt navn",
     "Your email address" : "Din e-postadresse",
+    "Book the appointment" : "Bestill avtalen",
+    "Reminder" : "Påminnelse",
     "before at" : "før ved",
     "Notification" : "Varsel",
     "Email" : "E-post",
@@ -178,8 +209,8 @@ OC.L10N.register(
     "Save time" : "Lagre tidspunkt",
     "Remove reminder" : "Fjern påminnelse",
     "on" : "på",
-    "at" : "på",
-    "+ Add reminder" : "+Legg til påminnelse",
+    "at" : "ved",
+    "+ Add reminder" : "+ Legg til påminnelse",
     "Add reminder" : "Legg til påminnelse",
     "_second_::_seconds_" : ["sekund","sekunder"],
     "_minute_::_minutes_" : ["minutt","minutter"],
@@ -187,7 +218,10 @@ OC.L10N.register(
     "_day_::_days_" : ["dag","dager"],
     "_week_::_weeks_" : ["uke","uker"],
     "Available" : "Tilgjengelig",
+    "Not available" : "Ikke tilgjengelig",
+    "Invitation sent" : "Invitasjon er sendt",
     "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
+    "{organizer} (organizer)" : "{organizer} (organisator)",
     "Free" : "Ledig",
     "Busy (tentative)" : "Opptatt (foreløpig)",
     "Busy" : "Opptatt",
@@ -198,15 +232,16 @@ OC.L10N.register(
     "Tentative" : "Foreløpig",
     "Create Talk room for this event" : "Opprett Talk-rom for denne hendelsen",
     "Show busy times" : "Vis opptatte tider",
-    "No attendees yet" : "Ingen deltagere enda",
+    "No attendees yet" : "Ingen deltakere enda",
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "Send email" : "Send e-post",
     "Chairperson" : "Ordstyrer",
     "Required participant" : "Påkrevd deltaker",
-    "Optional participant" : "Ønsket deltaker",
+    "Optional participant" : "Valgfri deltaker",
     "Non-participant" : "Ikke-deltaker",
     "Remove attendee" : "Fjern deltaker",
+    "Search for emails, users or contacts" : "Søk blant eposter, brukere eller kontaker",
     "No match found" : "Ingen treff",
     "(organizer)" : "(organisator)",
     "Remove color" : "Fjern farge",
@@ -218,6 +253,7 @@ OC.L10N.register(
     "to {endDate} at {endTime}" : "til {endDate}, {endTime}",
     "Repeat" : "Gjenta",
     "End repeat" : "Avslutt gjentakelse",
+    "Select to end repeat" : "Velg for å avslutte gjentakelse",
     "never" : "aldri",
     "on date" : "på dato",
     "after" : "etter",
@@ -228,33 +264,56 @@ OC.L10N.register(
     "fifth" : "femte",
     "last" : "siste",
     "Repeat every" : "Gjenta hver",
+    "By day of the month" : "På en dag i måneden",
     "On the" : "På den",
     "_month_::_months_" : ["måned","måneder"],
     "_year_::_years_" : ["år","år"],
     "weekday" : "ukedag",
-    "weekend day" : "helg",
+    "weekend day" : "helgedag",
+    "No recurrence" : "Ingen gjentakelse",
+    "No rooms or resources yet" : "Ingen rom eller ressurser enda",
+    "Has a projector" : "Har en projektor",
+    "Wheelchair accessible" : "Tilgjengelig for rullestol",
+    "Projector" : "Projektor",
+    "Search for resources or rooms" : "Søk etter ressurser eller rom",
     "available" : "tilgjengelig",
+    "Room type" : "Romtype",
+    "Minimum seating capacity" : "Minimum sittekapasitet",
     "More" : "Mer",
     "Update this occurrence" : "Oppdater denne hendelsen",
     "Update this and all future" : "Oppdater denne og fremtidige hendelser",
     "Public calendar does not exist" : "Offentlig kalender finnes ikke",
     "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
+    "Please select a time zone:" : "Vennligst velg en tidssone:",
     "Pick a time" : "Velg et tidspunkt",
     "Pick a date" : "Velg en dato",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
-    "on {formattedDate}" : "på {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} på {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "til {formattedDate} på {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "på {formattedDate} på {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} på {formattedTime}",
+    "on {formattedDate}" : "den {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "den {formattedDate} kl. {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
     "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
-    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og tidspunkt",
+    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og et tidspunkt",
+    "Type to search time zone" : "Skriv for å søke etter tidssone",
     "Global" : "Global",
+    "Select date" : "Velg dato",
+    "Select slot" : "Velg tidsrom",
+    "No slots available" : "Ingen tidsrom tilgjengelig",
+    "The slot for your appointment has been confirmed" : "Tidsrommet for din avtale har blitt bekreftet",
     "Time:" : "Tid:",
+    "Booked for:" : "Bestilt for:",
+    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Takk skal du ha. Bestillingen din fra {startDate} til {endDate} er bekreftet.",
+    "Book another appointment:" : "Bestill en annen avtale:",
+    "See all available slots" : "Se tilgjengelige tidsrom",
+    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tidsrommet for din avtale fra {startDate} toø {endDate} er ikke tilgjengelig lengre.",
+    "Please book a different slot:" : "Vennligst bestill et annet tidsrom:",
+    "Book an appointment with {name}" : "Bestill en avtale med {name}",
     "Personal" : "Personlig",
     "No more events today" : "Ingen flere hendelser i dag",
-    "Event does not exist" : "Avtalen finnes ikke",
+    "No upcoming events" : "Ingen kommende hendelser",
+    "Event does not exist" : "Hendelsen finnes ikke",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "Details" : "Detaljer",
@@ -267,10 +326,10 @@ OC.L10N.register(
     "Appointment" : "Avtale",
     "Business" : "Forretninger",
     "Education" : "Utdanning",
-    "Holiday" : "Ferie",
+    "Holiday" : "Helligdag",
     "Meeting" : "Møte",
     "Miscellaneous" : "Diverse",
-    "Non-working hours" : "Ikke-arbeidende tidspunkt",
+    "Non-working hours" : "Utenfor arbeidstid",
     "Not in office" : "Ikke på kontoret",
     "Phone call" : "Telefonsamtale",
     "Sick day" : "Sykedag",
@@ -283,25 +342,32 @@ OC.L10N.register(
     "Weekly" : "Ukentlig",
     "Monthly" : "Månedlig",
     "Yearly" : "Årlig",
+    "_%n time_::_%n times_" : ["%n gang","%n ganger"],
     "Untitled event" : "Hendelse uten tittel",
     "Untitled task" : "Oppgave uten tittel",
+    "Please ask your administrator to enable the Tasks App." : "Ta kontakt med din administrator for å sette opp Oppgaver-appen.",
     "Prev" : "Forrige",
     "Next" : "Neste",
     "Year" : "År",
+    "No events to display" : "Ingen hendelser å vise",
     "No events" : "Ingen hendelser",
+    "Create a new event or change the visible time-range" : "Opprett en ny hendelse eller endre på valgt tidsrom",
     "Other" : "Annet",
     "When shared show" : "Når delt vis",
-    "When shared show full event" : "Vis hele hendelsen når delt",
-    "When shared show only busy" : "Vis kun opptatt når delt",
-    "When shared hide this event" : "Skjul denne hendelsen når delt",
+    "When shared show full event" : "Vis hele hendelsen om den deles",
+    "When shared show only busy" : "Vis kun opptatt om den deles",
+    "When shared hide this event" : "Skjul denne hendelsen om den deles",
     "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
     "Add a location" : "Legg til et sted",
     "Add a description" : "Legg til en beskrivelse",
     "Status" : "Status",
     "Confirmed" : "Bekreftet",
     "Canceled" : "Avbrutt",
+    "Confirmation about the overall status of the event." : "Bekreftelse om den generelle statusen til arrangementet.",
     "Show as" : "Vis som",
+    "Take this event into account when calculating free-busy information." : "Ta hensyn til denne hendelsen når det beregnes ledig-opptatt-informasjon.",
     "Categories" : "Kategorier",
+    "Categories help you to structure and organize your events." : "Kategorier hjelper deg med å strukturere og organisere arrangementene dine.",
     "Search or add categories" : "Søk eller legg til kategorier",
     "Add this as a new category" : "Legg til som ny kategori",
     "Custom color" : "Tilpasset farge",
@@ -319,7 +385,7 @@ OC.L10N.register(
     "Review" : "Anmeldelse",
     "Meet" : "Møte",
     "Planning" : "Planlegge",
-    "Office" : "Office",
+    "Office" : "Kontor",
     "Mail" : "E-post",
     "Soccer" : "Fotball",
     "Gaming" : "Gaming",
@@ -357,7 +423,7 @@ OC.L10N.register(
     "Video-conference" : "Videokonferanse",
     "Conference-call" : "Telefonkonferanse",
     "Video-call" : "Videosamtale",
-    "Video-chat" : "Videosamtale",
+    "Video-chat" : "Videochat",
     "Video-meeting" : "Videokonferanse",
     "Call" : "Ringe",
     "Calling" : "Ringer",
