@@ -5,6 +5,7 @@ OC.L10N.register(
     "Open »%s«" : "Dobrir « %s »",
     "Cheers!" : "A lèu !",
     "Upcoming events" : "Eveniments venents",
+    "Appointments" : "Rendetz-vos",
     "Confirm" : "Confirmar",
     "Date:" : "Data :",
     "Where:" : "Ont :",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Next day" : "Jorn seguent",
     "Next week" : "Setmana seguenta",
     "Next month" : "Mes seguent",
+    "New event" : "Eveniment novèl",
     "Today" : "Uèi",
     "Day" : "Jorn",
     "Week" : "Aquesta setmana",
@@ -26,6 +28,7 @@ OC.L10N.register(
     "Copy link" : "Copiar lo ligam",
     "Edit" : "Modificar",
     "Delete" : "Suprimir",
+    "Add new" : "Apondre novèl",
     "Untitled calendar" : "Calendièr sens nom",
     "Edit name" : "Modificar lo nom",
     "Saving name …" : "Enregistrament del nom …",
@@ -42,6 +45,8 @@ OC.L10N.register(
     "can edit" : "pòt modificar",
     "+ New calendar" : "+ Calendièr novèl",
     "New calendar" : "Calendièr novèl",
+    "Name for new calendar" : "Nom del calendièr novèl",
+    "Creating calendar …" : "Creacion del calendièr…",
     "Name" : "Nom",
     "Deleted" : "Suprimit",
     "Restore" : "Restaurar",
@@ -66,7 +71,7 @@ OC.L10N.register(
     "Duration" : "Durada",
     "to" : "a",
     "Add" : "Apondre",
-    "Monday" : "diluns",
+    "Monday" : "Diluns",
     "Tuesday" : "Dimars",
     "Wednesday" : "Dimècres",
     "Thursday" : "Dijòus",
@@ -93,11 +98,16 @@ OC.L10N.register(
     "_day_::_days_" : ["jorn","jorns"],
     "_week_::_weeks_" : ["setmana","setmanas"],
     "Available" : "Disponible",
+    "Free" : "Liure",
+    "Busy (tentative)" : "Ocupat (provisòri)",
     "Busy" : "Ocupat",
+    "Out of office" : "Fòra del burèu",
     "Unknown" : "Desconegut",
     "Accept" : "Acceptar",
+    "Decline" : "Declinar",
     "Tentative" : "Provisòri",
     "Send email" : "Enviar email",
+    "Event title" : "Títol de l’eveniment",
     "All day" : "Tota la jornada",
     "Repeat" : "Repetir",
     "never" : "pas jamai",
@@ -110,8 +120,15 @@ OC.L10N.register(
     "last" : "darrièr",
     "_month_::_months_" : ["mes","mese"],
     "_year_::_years_" : ["annada","annadas"],
+    "weekday" : "dimenjada",
+    "weekend day" : "jorn de la setmana",
+    "No recurrence" : "Cap d’ocurréncia",
     "Suggestions" : "Suggestions",
     "Add resource" : "Apondre ressorsa",
+    "available" : "disponible",
+    "unavailable" : "indisponible",
+    "Room type" : "Tipe de sala",
+    "Any" : "Quina que siá",
     "More" : "Mai",
     "Pick a time" : "Causir una ora",
     "Pick a date" : "Causir una data",
@@ -120,6 +137,7 @@ OC.L10N.register(
     "Type to search time zone" : "Picar per cercar un fus orari",
     "Global" : "Global",
     "Personal" : "Personal",
+    "Create a new event" : "Crear un eveniment novèl",
     "[Today]" : "[Uèi]",
     "[Tomorrow]" : "[Deman]",
     "[Yesterday]" : "[Ièr]",
@@ -157,13 +175,34 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
     "Commuting" : "En comunicacion",
+    "Invoice" : "Factura",
+    "Finance" : "Finança",
+    "Bank" : "Banca",
+    "Money" : "Moneda",
+    "Wedding" : "Maridatge",
+    "Dog" : "Can",
+    "Concert" : "Concèrt",
+    "Festival" : "Festenal",
+    "Theater" : "Teatre",
+    "Theatre" : "Teatre",
     "Presentation" : "Presentacion",
     "Talk" : "Talk",
+    "Speech" : "Discutida",
+    "Election" : "Eleccion",
+    "Voting" : "Vòte",
+    "Vote" : "Vòte",
+    "Garden" : "Òrt",
+    "Farm" : "Bòria",
     "Movie" : "Film",
     "Cinema" : "Cinèma",
+    "Graduation" : "Remesa dels diplòmas",
+    "Brainstorm" : "Pluèja d’idèa",
+    "Audit" : "Audit",
+    "Inspection" : "Inspeccion",
     "Mail" : "Mail",
     "Gaming" : "Vidèo-jòc",
     "Bicycle" : "Bicicleta",
+    "Bike" : "Bicicleta",
     "Fishing" : "Pesca",
     "Hiking" : "Escalada",
     "Art" : "Arts",
