@@ -47,8 +47,6 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
     "Add new" : "Adaugă nou",
     "Untitled calendar" : "Calendar nedenumit",
-    "Disable calendar" : "Dezactivează calendarul",
-    "Enable calendar" : "Activează calendarul",
     "Edit name" : "Modifică numele",
     "Saving name …" : "Se salvează numele ...",
     "Edit color" : "Modifică culoarea",
@@ -122,7 +120,6 @@ OC.L10N.register(
     "Calendar to import into" : "Calendarul în care se importă",
     "Cancel" : "Anulează",
     "_Import calendar_::_Import calendars_" : ["Importă calendar","Importă calendare","Importă calendare"],
-    "{filename} is an unsupported file-type" : "{filename} este un fişier nesuportat",
     "{filename} could not be parsed" : "{filename} nu a putut fi analizat",
     "No valid files found, aborting import" : "Nu au fost găsite fişiere valide, importarea se opreşte",
     "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
@@ -154,7 +151,6 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
     "Personal availability settings" : "Setări de disponibilitate",
     "Show keyboard shortcuts" : "Arată scurtături",
-    "Settings & import" : "Setări și import",
     "No reminder" : "Fără mementouri",
     "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
     "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
