@@ -51,7 +51,7 @@ OC.L10N.register(
     "Email" : "อีเมล",
     "Unknown" : "ไม่ทราบ",
     "Accept" : "ยอมรับ",
-    "Decline" : "ลดลง",
+    "Decline" : "ปฏิเสธ",
     "Tentative" : "ชั่วคราว",
     "Send email" : "ส่งอีเมล",
     "Repeat" : "ทำซ้ำ",
@@ -75,6 +75,7 @@ OC.L10N.register(
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
     "Status" : "สถานะ",
     "Confirmed" : "ได้รับการยืนยันแล้ว",
+    "Categories" : "หมวดหมู่",
     "Commuting" : "กำลังเดินทาง",
     "Presentation" : "งานนำเสนอ",
     "Office" : "สำนักงาน",
