@@ -6,22 +6,34 @@ OC.L10N.register(
     "Today" : "آج",
     "Week" : "ہفتہ",
     "Month" : "ماہ",
-    "Download" : "ڈاؤن لوڈ",
+    "Edit" : "تدوین کریں",
     "Delete" : "حذف کریں",
     "Share link" : "اشتراک لنک",
     "can edit" : "تبدیل کر سکے ھیں",
     "New calendar" : "جدید کیلنڈر",
+    "Name" : "اسم",
+    "Deleted" : "حذف شدہ ",
+    "Restore" : "بحال",
     "Cancel" : "منسوخ کریں",
-    "Email" : "email",
-    "never" : "never",
-    "Repeat" : "دہرایں",
+    "Location" : "مقام",
+    "Description" : "تصریح",
+    "Add" : "شامل کریں",
     "Monday" : "سوموار",
-    "More" : "مزید",
+    "Tuesday" : "منگل",
+    "Wednesday" : "بدھ",
+    "Thursday" : "جمعرات",
+    "Friday" : "جمعہ",
+    "Saturday" : "ہفتہ",
+    "Sunday" : "اتوار",
     "Save" : "حفظ",
+    "Email" : "email",
+    "Repeat" : "دہرایں",
+    "never" : "never",
+    "More" : "مزید",
     "Personal" : "شخصی",
     "Close" : "بند ",
-    "today" : "آج",
-    "Location" : "مقام",
-    "Description" : "تصریح"
+    "Next" : "اگلا",
+    "Other" : "دیگر",
+    "Birthday" : "سالگرہ"
 },
 "nplurals=2; plural=(n != 1);");
